==> cdi-tck-2.0.6-dist.zip: org/jboss/cdi/tck/tests/lookup/injection/parameterized/ConsumerActualType.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.tests.lookup.injection.parameterized;

import java.util.List;

import javax.inject.Inject;

public class ConsumerActualType {

    @Inject
    Dao<Integer, String> dao;

    @Inject
    Dao<Object, Object> objectDao;

    @Inject
    @IntegerPowered
    Dao<Integer, String> integerStringDao;

    @Inject
    @IntegerPowered
    Dao<Integer, List<String>> integerListOfStringsDao;

    public Dao<Integer, String> getDao() {
        return dao;
    }

    public Dao<Integer, String> getIntegerStringDao() {
        return integerStringDao;
    }

    public Dao<Integer, List<String>> getIntegerListOfStringsDao() {
        return integerListOfStringsDao;
    }

    public Dao<Object, Object> getObjectDao() {
        return objectDao;
    }

}

==> cdi-tck-3.0.2-dist.zip: org/jboss/cdi/tck/tests/lookup/injection/parameterized/ConsumerActualType.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.tests.lookup.injection.parameterized;

import java.util.List;

import jakarta.inject.Inject;

public class ConsumerActualType {

    @Inject
    Dao<Integer, String> dao;

    @Inject
    Dao<Object, Object> objectDao;

    @Inject
    @IntegerPowered
    Dao<Integer, String> integerStringDao;

    @Inject
    @IntegerPowered
    Dao<Integer, List<String>> integerListOfStringsDao;

    public Dao<Integer, String> getDao() {
        return dao;
    }

    public Dao<Integer, String> getIntegerStringDao() {
        return integerStringDao;
    }

    public Dao<Integer, List<String>> getIntegerListOfStringsDao() {
        return integerListOfStringsDao;
    }

    public Dao<Object, Object> getObjectDao() {
        return objectDao;
    }

}
